@@ -81,11 +81,11 @@ mod tests {
         assert_cli!("uninstall", "--all", "tiny");
         assert_cli!("install", "tiny@1", "tiny@2");
         assert_cli!("asdf", "install", "tiny");
-        assert_cli_snapshot!("asdf", "list", "tiny", @r#"
+        assert_cli_snapshot!("asdf", "list", "tiny", @r"
         1.0.1
         2.1.0
         3.1.0
-        "#);
+        ");
     }
 
     #[test]
@@ -93,9 +93,7 @@ mod tests {
         reset();
         assert_cli!("uninstall", "--all", "tiny");
         assert_cli!("install", "tiny@3.1.0");
-        assert_cli_snapshot!("asdf", "current", "tiny", @r###"
-        3.1.0
-        "###);
+        assert_cli_snapshot!("asdf", "current", "tiny", @"3.1.0");
     }
 
     #[test]
