@@ -91,13 +91,13 @@ mod tests {
         assert_cli!("install", "tiny@3.0.1", "tiny@3.1.0");
         create_dir_all("../data/tmp/tiny").unwrap();
         assert_cli!("link", "tiny@9.8.7", "../data/tmp/tiny");
-        assert_cli_snapshot!("ls", "tiny", @r###"
+        assert_cli_snapshot!("ls", "tiny", @r"
         tiny  1.0.1                                       
         tiny  2.1.0                                       
         tiny  3.0.1                                       
         tiny  3.1.0            ~/cwd/.test-tool-versions 3
         tiny  9.8.7 (symlink)
-        "###);
+        ");
         assert_cli!("uninstall", "tiny@9.8.7");
     }
 }
